### Python version >= 3.6

## Common code for myself.

## Features:

- AppTool class

    - Combine config & config_local & config_test (if --test)
    - Act as dict to get config by key (connected by dot), it can be overrited by ENV variable 
    - logger helper (pre-configged email handler)
    - Pre-configged SMTP email client
    - @log annotation.

- Utility functions
    - email helper
    - load & dump json
    - @benchmark annotation
    - OS detector
    - @deprecated annotation
    - get home dir
    - deep merge
    - Get windows folders
    - string alignment for Chinese
    - get dict value by key (connected by dot)
    - now, today
    - random_sleep

- GetCh class
    - input value for multiple platforms

## TODO:

- send_email support CC.